[Lldb-commits] [lldb] r112824 - in /lldb/trunk/test: array_types/TestArrayTypes.py bitfields/TestBitfields.py class_types/TestClassTypes.py function_types/TestFunctionTypes.py global_variables/TestGlobalVariables.py hello_world/TestHelloWorld.py set_values/TestSetValues.py unsigned_types/TestUnsignedTypes.py

Johnny Chen johnny.chen at apple.com
Thu Sep 2 08:59:20 PDT 2010


Author: johnny
Date: Thu Sep  2 10:59:20 2010
New Revision: 112824

URL: http://llvm.org/viewvc/llvm-project?rev=112824&view=rev
Log:
(query-replace "variable list" "frame variable")

Modified:
    lldb/trunk/test/array_types/TestArrayTypes.py
    lldb/trunk/test/bitfields/TestBitfields.py
    lldb/trunk/test/class_types/TestClassTypes.py
    lldb/trunk/test/function_types/TestFunctionTypes.py
    lldb/trunk/test/global_variables/TestGlobalVariables.py
    lldb/trunk/test/hello_world/TestHelloWorld.py
    lldb/trunk/test/set_values/TestSetValues.py
    lldb/trunk/test/unsigned_types/TestUnsignedTypes.py

Modified: lldb/trunk/test/array_types/TestArrayTypes.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/array_types/TestArrayTypes.py?rev=112824&r1=112823&r2=112824&view=diff
==============================================================================
--- lldb/trunk/test/function_types/TestFunctionTypes.py (original)
+++ lldb/trunk/test/function_types/TestFunctionTypes.py Thu Sep  2 10:59:20 2010
@@ -30,7 +30,7 @@
             substrs = [' resolved, hit count = 1'])
 
         # Check that the 'callback' variable display properly.
-        self.expect("variable list callback", VARIABLES_DISPLAYED_CORRECTLY,
+        self.expect("frame variable callback", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = '(int (*)(char const *)) callback =')
 
         # And that we can break on the callback function.

Modified: lldb/trunk/test/global_variables/TestGlobalVariables.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/global_variables/TestGlobalVariables.py?rev=112824&r1=112823&r2=112824&view=diff
==============================================================================
--- lldb/trunk/test/hello_world/TestHelloWorld.py (original)
+++ lldb/trunk/test/hello_world/TestHelloWorld.py Thu Sep  2 10:59:20 2010
@@ -18,7 +18,7 @@
         self.buildDsym()
         self.hello_world_python(useLaunchAPI = False)
 
-    #@unittest2.expectedFailure
+    @unittest2.expectedFailure
     def test_with_dwarf_and_process_launch_api(self):
         """Create target, breakpoint, launch a process, and then kill it.
 

Modified: lldb/trunk/test/set_values/TestSetValues.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/set_values/TestSetValues.py?rev=112824&r1=112823&r2=112824&view=diff
==============================================================================
--- lldb/trunk/test/unsigned_types/TestUnsignedTypes.py (original)
+++ lldb/trunk/test/unsigned_types/TestUnsignedTypes.py Thu Sep  2 10:59:20 2010
@@ -32,7 +32,7 @@
             substrs = [' resolved, hit count = 1'])
 
         # Test that unsigned types display correctly.
-        self.expect("variable list -a", VARIABLES_DISPLAYED_CORRECTLY,
+        self.expect("frame variable -a", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = "the_unsigned_char = (unsigned char) 'c'",
             substrs = ["the_unsigned_short = (short unsigned int) 0x0063",
                        "the_unsigned_int = (unsigned int) 0x00000063",





More information about the lldb-commits mailing list
--- lldb/trunk/test/array_types/TestArrayTypes.py (original)
+++ lldb/trunk/test/array_types/TestArrayTypes.py Thu Sep  2 10:59:20 2010
@@ -11,7 +11,7 @@
 
     @unittest2.skipUnless(sys.platform.startswith("darwin"), "requires Darwin")
     def test_with_dsym_and_run_command(self):
         """Test 'variable list var_name' on some variables with array types."""
         self.buildDsym()
         self.array_types()
 
@@ -22,7 +22,7 @@
         self.array_types_python()
 
     def test_with_dwarf_and_run_command(self):
         """Test 'variable list var_name' on some variables with array types."""
         self.buildDwarf()
         self.array_types()
 
@@ -32,7 +32,7 @@
         self.array_types_python()
 
     def array_types(self):
         """Test 'variable list var_name' on some variables with array types."""
         exe = os.path.join(os.getcwd(), "a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
 
@@ -53,7 +53,7 @@
 
         # Issue 'variable list' command on several array-type variables.
 
-        self.expect("variable list strings", VARIABLES_DISPLAYED_CORRECTLY,
+        self.expect("frame variable strings", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = '(char *[4])',
             substrs = ['(char *) strings[0]',
                        '(char *) strings[1]',
@@ -64,14 +64,14 @@
                        'Bonjour',
                        'Guten Tag'])
 
-        self.expect("variable list char_16", VARIABLES_DISPLAYED_CORRECTLY,
+        self.expect("frame variable char_16", VARIABLES_DISPLAYED_CORRECTLY,
             substrs = ['(char) char_16[0]',
                        '(char) char_16[15]'])
 
-        self.expect("variable list ushort_matrix", VARIABLES_DISPLAYED_CORRECTLY,
+        self.expect("frame variable ushort_matrix", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = '(unsigned short [2][3])')
 
-        self.expect("variable list long_6", VARIABLES_DISPLAYED_CORRECTLY,
+        self.expect("frame variable long_6", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = '(long [6])')
 
     def array_types_python(self):
@@ -11,7 +11,7 @@
     @unittest2.skipUnless(sys.platform.startswith("darwin"), "requires Darwin")
     def test_with_dsym_and_run_command(self):
-        """Test 'variable list var_name' on some variables with array types."""
+        """Test 'frame variable var_name' on some variables with array types."""
         self.buildDsym()
         self.array_types()
@@ -22,7 +22,7 @@
 
     def test_with_dwarf_and_run_command(self):
-        """Test 'variable list var_name' on some variables with array types."""
+        """Test 'frame variable var_name' on some variables with array types."""
         self.buildDwarf()
         self.array_types()
@@ -32,7 +32,7 @@
 
     def array_types(self):
-        """Test 'variable list var_name' on some variables with array types."""
+        """Test 'frame variable var_name' on some variables with array types."""
         exe = os.path.join(os.getcwd(), "a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)

Modified: lldb/trunk/test/bitfields/TestBitfields.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/bitfields/TestBitfields.py?rev=112824&r1=112823&r2=112824&view=diff
==============================================================================
--- lldb/trunk/test/bitfields/TestBitfields.py (original)
+++ lldb/trunk/test/bitfields/TestBitfields.py Thu Sep  2 10:59:20 2010
@@ -12,7 +12,7 @@
     @unittest2.skipUnless(sys.platform.startswith("darwin"), "requires Darwin")
     @unittest2.expectedFailure
     def test_with_dsym_and_run_command(self):
         """Test 'variable list ...' on a variable with bitfields."""
         self.buildDsym()
         self.bitfields_variable()
 
@@ -24,7 +24,7 @@
 
     @unittest2.expectedFailure
     def test_with_dwarf_and_run_command(self):
         """Test 'variable list ...' on a variable with bitfields."""
         self.buildDwarf()
         self.bitfields_variable()
 
@@ -34,7 +34,7 @@
         self.bitfields_variable_python()
 
     def bitfields_variable(self):
         """Test 'variable list ...' on a variable with bitfields."""
         exe = os.path.join(os.getcwd(), "a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
 
@@ -54,7 +54,7 @@
             substrs = [' resolved, hit count = 1'])
 
         # This should display correctly.
-        self.expect("variable list bits", VARIABLES_DISPLAYED_CORRECTLY,
+        self.expect("frame variable bits", VARIABLES_DISPLAYED_CORRECTLY,
             substrs = ['(uint32_t:1) b1 = 0x00000001,',
                        '(uint32_t:2) b2 = 0x00000003,',
                        '(uint32_t:3) b3 = 0x00000007,',
@@ -66,7 +66,7 @@
 
         # And so should this.
         # rdar://problem/8348251
-        self.expect("variable list", VARIABLES_DISPLAYED_CORRECTLY,
+        self.expect("frame variable", VARIABLES_DISPLAYED_CORRECTLY,
             substrs = ['(uint32_t:1) b1 = 0x00000001,',
                        '(uint32_t:2) b2 = 0x00000003,',
                        '(uint32_t:3) b3 = 0x00000007,',
@@ -12,7 +12,7 @@
     @unittest2.expectedFailure
     def test_with_dsym_and_run_command(self):
-        """Test 'variable list ...' on a variable with bitfields."""
+        """Test 'frame variable ...' on a variable with bitfields."""
         self.buildDsym()
         self.bitfields_variable()
@@ -24,7 +24,7 @@
     @unittest2.expectedFailure
     def test_with_dwarf_and_run_command(self):
-        """Test 'variable list ...' on a variable with bitfields."""
+        """Test 'frame variable ...' on a variable with bitfields."""
         self.buildDwarf()
         self.bitfields_variable()
@@ -34,7 +34,7 @@
 
     def bitfields_variable(self):
-        """Test 'variable list ...' on a variable with bitfields."""
+        """Test 'frame variable ...' on a variable with bitfields."""
         exe = os.path.join(os.getcwd(), "a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)

Modified: lldb/trunk/test/class_types/TestClassTypes.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/class_types/TestClassTypes.py?rev=112824&r1=112823&r2=112824&view=diff
==============================================================================
--- lldb/trunk/test/class_types/TestClassTypes.py (original)
+++ lldb/trunk/test/class_types/TestClassTypes.py Thu Sep  2 10:59:20 2010
@@ -11,7 +11,7 @@
 
     @unittest2.skipUnless(sys.platform.startswith("darwin"), "requires Darwin")
     def test_with_dsym_and_run_command(self):
         """Test 'variable list this' when stopped on a class constructor."""
         self.buildDsym()
         self.class_types()
 
@@ -22,11 +22,11 @@
         self.breakpoint_creation_by_filespec_python()
 
     # rdar://problem/8378863
-    # "variable list this" returns
+    # "frame variable this" returns
     # error: unable to find any variables named 'this'
     @unittest2.expectedFailure
     def test_with_dwarf_and_run_command(self):
         """Test 'variable list this' when stopped on a class constructor."""
         self.buildDwarf()
         self.class_types()
 
@@ -36,7 +36,7 @@
         self.breakpoint_creation_by_filespec_python()
 
     def class_types(self):
         """Test 'variable list this' when stopped on a class constructor."""
         exe = os.path.join(os.getcwd(), "a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
 
@@ -56,7 +56,7 @@
             substrs = [' resolved, hit count = 1'])
 
         # We should be stopped on the ctor function of class C.
-        self.expect("variable list this", VARIABLES_DISPLAYED_CORRECTLY,
+        self.expect("frame variable this", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = '(class C *const) this = ')
 
     def breakpoint_creation_by_filespec_python(self):
@@ -11,7 +11,7 @@
     @unittest2.skipUnless(sys.platform.startswith("darwin"), "requires Darwin")
     def test_with_dsym_and_run_command(self):
-        """Test 'variable list this' when stopped on a class constructor."""
+        """Test 'frame variable this' when stopped on a class constructor."""
         self.buildDsym()
         self.class_types()
@@ -22,11 +22,11 @@
     @unittest2.expectedFailure
     def test_with_dwarf_and_run_command(self):
-        """Test 'variable list this' when stopped on a class constructor."""
+        """Test 'frame variable this' when stopped on a class constructor."""
         self.buildDwarf()
         self.class_types()
@@ -36,7 +36,7 @@
 
     def class_types(self):
-        """Test 'variable list this' when stopped on a class constructor."""
+        """Test 'frame variable this' when stopped on a class constructor."""
         exe = os.path.join(os.getcwd(), "a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)

Modified: lldb/trunk/test/function_types/TestFunctionTypes.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/function_types/TestFunctionTypes.py?rev=112824&r1=112823&r2=112824&view=diff
==============================================================================
--- lldb/trunk/test/global_variables/TestGlobalVariables.py (original)
+++ lldb/trunk/test/global_variables/TestGlobalVariables.py Thu Sep  2 10:59:20 2010
@@ -10,7 +10,7 @@
     mydir = "global_variables"
 
     def test_global_variables(self):
         """Test 'variable list -s -a' which omits args and shows scopes."""
         exe = os.path.join(os.getcwd(), "a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
 
@@ -30,7 +30,7 @@
             substrs = [' resolved, hit count = 1'])
 
         # Check that GLOBAL scopes are indicated for the variables.
-        self.expect("variable list -s -a", VARIABLES_DISPLAYED_CORRECTLY,
+        self.expect("frame variable -s -a", VARIABLES_DISPLAYED_CORRECTLY,
             substrs = ['GLOBAL: g_file_static_cstr',
                        '"g_file_static_cstr"',
                        'GLOBAL: g_file_global_int',
@@ -10,7 +10,7 @@
 
     def test_global_variables(self):
-        """Test 'variable list -s -a' which omits args and shows scopes."""
+        """Test 'frame variable -s -a' which omits args and shows scopes."""
         exe = os.path.join(os.getcwd(), "a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)

Modified: lldb/trunk/test/hello_world/TestHelloWorld.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/hello_world/TestHelloWorld.py?rev=112824&r1=112823&r2=112824&view=diff
==============================================================================
--- lldb/trunk/test/set_values/TestSetValues.py (original)
+++ lldb/trunk/test/set_values/TestSetValues.py Thu Sep  2 10:59:20 2010
@@ -42,8 +42,8 @@
             substrs = [' resolved, hit count = 1'])
 
         # main.c:15
-        # Check that 'variable list' displays the correct data type and value.
-        self.expect("variable list", VARIABLES_DISPLAYED_CORRECTLY,
+        # Check that 'frame variable' displays the correct data type and value.
+        self.expect("frame variable", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = "i = (char) 'a'")
 
         # TODO:
@@ -52,8 +52,8 @@
         self.runCmd("continue")
 
         # main.c:36
-        # Check that 'variable list' displays the correct data type and value.
-        self.expect("variable list", VARIABLES_DISPLAYED_CORRECTLY,
+        # Check that 'frame variable' displays the correct data type and value.
+        self.expect("frame variable", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = "i = (short unsigned int) 0x0021")
 
         # TODO:
@@ -62,8 +62,8 @@
         self.runCmd("continue")
 
         # main.c:57
-        # Check that 'variable list' displays the correct data type and value.
-        self.expect("variable list", VARIABLES_DISPLAYED_CORRECTLY,
+        # Check that 'frame variable' displays the correct data type and value.
+        self.expect("frame variable", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = "i = (long int) 33")
 
         # TODO:
@@ -72,8 +72,8 @@
         self.runCmd("continue")
 
         # main.c:78
-        # Check that 'variable list' displays the correct data type and value.
-        self.expect("variable list", VARIABLES_DISPLAYED_CORRECTLY,
+        # Check that 'frame variable' displays the correct data type and value.
+        self.expect("frame variable", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = "i = (double) 3.14159")
 
         # TODO:
@@ -82,8 +82,8 @@
         self.runCmd("continue")
 
         # main.c:85
-        # Check that 'variable list' displays the correct data type and value.
-        self.expect("variable list", VARIABLES_DISPLAYED_CORRECTLY,
+        # Check that 'frame variable' displays the correct data type and value.
+        self.expect("frame variable", VARIABLES_DISPLAYED_CORRECTLY,
             startstr = "i = (long double) ")
 
         # TODO:

Modified: lldb/trunk/test/unsigned_types/TestUnsignedTypes.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/unsigned_types/TestUnsignedTypes.py?rev=112824&r1=112823&r2=112824&view=diff
==============================================================================